searchNodes=[{"doc":"Riptide Interceptors let you define simple rules using Elixir&#39;s pattern matching that trigger conditionally when data is written or read. Each one is defined as a module that can be added to your Riptide configuration for easy enabling/disabling. config :riptide, interceptors: [ TodoList.Permissions, TodoList.Todo.Created, TodoList.Todo.Alert ] Every Interceptor in this list is called in order for every Mutation and Query processed Mutation Interceptors Mutation interceptors run as a mutation is being processed. The callbacks are called for each part of the paths in the mutation so you can define a pattern to match any kind of mutation. The arguments passed to them are path: A string list representing the path where the data is being written layer: The merge and delete that is occuring at the path mut: The full, original mutation state: The state of the connection which can be used to store things like the currently authed user mutation_before This runs before a mutation is written. It&#39;s best used to perform validations to make sure the data looks right, augmenting mutations with information that is known by the server only, or data denormalization. Here is an example that keeps track of the time when a Todo was marked complete defmodule Todo.Created do use Riptide.Interceptor def mutation_before([&quot;todos&quot;, _key], %{ merge: %{ &quot;complete&quot; =&gt; true }}, state) do { :merge, %{ &quot;times&quot; =&gt; %{ &quot;completed&quot; =&gt; :os.system_time(:millisecond) } } } end end The valid responses are :ok - Returns successfully but doesn&#39;t modify anything {:error, err} - Halts processing of interceptors and returns the error {:combine, mut} - Combines mut with the input mutation before writing {:merge, map} - Convenience version of :combine that merges map at the current path {:delete, map} - Convenience version of :combine that deletes map at the current path mutation_effect This interceptor can be used to schedule work to be done after a mutation is successfully written. It can be used to trigger side effects like sending an email or syncing data with a third party system. defmodule Todo.Created do use Riptide.Interceptor def mutation_before([&quot;todos&quot;, _key], %{ merge: %{ &quot;complete&quot; =&gt; true }}, state) do { :merge, %{ &quot;times&quot; =&gt; %{ &quot;completed&quot; =&gt; :os.system_time(:millisecond) } } } end end The valid responses are :ok - Returns successfully but doesn&#39;t schedule any work {fun, args} - Calls fun in the current module with args {module, fun, args} - Calls fun in module with args Query Interceptors Query interceptors run as a query is being processed. They can be used to allow/disallow access to certain paths or even expose third party data sources. Unlike the mutation interceptors they are called only once for each path requested by a query. The arguments passed to them are path: A string list representing the full path where the data is being written opts: The options for the query at this path state: The state of the connection which can be used to store things like the currently authed user query_before This runs before data is read. A common way to use it is to control access to data defmodule Todo.Permissions do use Riptide.Interceptor def query_before([&quot;secrets&quot; | _rest], _opts, state) do case state do state.user === &quot;bad-guy&quot; -&gt; {:error, :auth_error} true -&gt; :ok end end end The valid responses are :ok - Returns successfully {:error, err} - Halts processing of interceptors and returns the error query_resolve This is run before data is fetched from the store. This interceptor allows you to return data for the query and skip reading from the store. They effectively create virtual paths. defmodule Todo.Twilio do use Riptide.Interceptor def query_resolve([&quot;twilio&quot;, &quot;numbers&quot; | _rest], _opts, state) do TwilioApi.numbers() |&gt; case do {:ok, result} -&gt; Kernel.get_in(result, rest) {:error, err} -&gt; {:error, err} end end end The valid responses are nil - Skips this interceptor and continues processing any_value - Returns any_value as the data under the requested path","ref":"Riptide.Interceptor.html","title":"Riptide.Interceptor","type":"behaviour"},{"doc":"","ref":"Riptide.Interceptor.html#c:mutation_after/4","title":"Riptide.Interceptor.mutation_after/4","type":"callback"},{"doc":"Trigger mutation_before callback on configured interceptors for given mutation","ref":"Riptide.Interceptor.html#mutation_before/2","title":"Riptide.Interceptor.mutation_before/2","type":"function"},{"doc":"Trigger mutation_before callback on interceptors for given mutation","ref":"Riptide.Interceptor.html#mutation_before/3","title":"Riptide.Interceptor.mutation_before/3","type":"function"},{"doc":"","ref":"Riptide.Interceptor.html#c:mutation_before/4","title":"Riptide.Interceptor.mutation_before/4","type":"callback"},{"doc":"Trigger mutation_effect callback on configured interceptors for given mutation","ref":"Riptide.Interceptor.html#mutation_effect/2","title":"Riptide.Interceptor.mutation_effect/2","type":"function"},{"doc":"Trigger mutation_effect callback on interceptors for given mutation","ref":"Riptide.Interceptor.html#mutation_effect/3","title":"Riptide.Interceptor.mutation_effect/3","type":"function"},{"doc":"","ref":"Riptide.Interceptor.html#c:mutation_effect/4","title":"Riptide.Interceptor.mutation_effect/4","type":"callback"},{"doc":"Trigger query_before callback on configured interceptors for given query","ref":"Riptide.Interceptor.html#query_before/2","title":"Riptide.Interceptor.query_before/2","type":"function"},{"doc":"Trigger query_before callback on interceptors for given query","ref":"Riptide.Interceptor.html#query_before/3","title":"Riptide.Interceptor.query_before/3","type":"function"},{"doc":"","ref":"Riptide.Interceptor.html#c:query_before/3","title":"Riptide.Interceptor.query_before/3","type":"callback"},{"doc":"Trigger query_resolve callback on configured interceptors for given query","ref":"Riptide.Interceptor.html#query_resolve/2","title":"Riptide.Interceptor.query_resolve/2","type":"function"},{"doc":"Trigger query_resolve callback on interceptors for given query","ref":"Riptide.Interceptor.html#query_resolve/3","title":"Riptide.Interceptor.query_resolve/3","type":"function"},{"doc":"","ref":"Riptide.Interceptor.html#c:query_resolve/3","title":"Riptide.Interceptor.query_resolve/3","type":"callback"},{"doc":"","ref":"Riptide.Websocket.Client.html","title":"Riptide.Websocket.Client","type":"module"},{"doc":"","ref":"Riptide.Websocket.Client.html#start_link/2","title":"Riptide.Websocket.Client.start_link/2","type":"function"}]